//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Data/RealDataPresenter.cpp
//! @brief     Implements class RealDataPresenter.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Data/RealDataPresenter.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Device/DatafileItem.h"
#include "GUI/View/Frame/MaskEditingFrame.h"
#include "GUI/View/Frame/Plot2DFrame.h"
#include "GUI/View/Frame/Plot2DWithProjectionFrame.h"
#include "GUI/View/Frame/SpecularFrame.h"

RealDataPresenter::RealDataPresenter(QWidget* parent)
    : ItemComboWidget(parent)
{
    registerWidget("Heat Map", create_new<Plot2DFrame>);
    registerWidget("Projections", create_new<Plot2DWithProjectionFrame>);
    registerWidget("Mask Editor", create_new<MaskEditingFrame>);
    registerWidget("Reflectometry (Graph only)", create_new<SpecularFrame>);
}

QString RealDataPresenter::itemPresentation() const
{
    if (!realItem())
        return ItemComboWidget::selectedPresentation();

    if (realItem()->presentationType().isEmpty())
        return ItemComboWidget::itemPresentation();

    return realItem()->presentationType();
}

void RealDataPresenter::setPresentation(const QString& presentationType)
{
    ItemComboWidget::setPresentation(presentationType);
    if (realItem() && !presentationType.isEmpty())
        realItem()->setPresentationType(presentationType);
}

QStringList RealDataPresenter::activePresentationList() const
{
    ASSERT(realItem());

    QStringList result;
    if (realItem()->rank() == 2)
        result << "Heat Map"
               << "Projections"
               << "Mask Editor";
    else if (realItem()->rank() == 1) {
        result << "Reflectometry (Graph only)";
    } else
        ASSERT_NEVER;
    return result;
}
