//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Frame/Fit2DFrame.h
//! @brief     Defines class Fit2DFrame.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H
#define BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H

#include "GUI/View/Access/DataAccessWidget.h"

class ColorMapCanvas;
class FitFlowWidget;
class Scale2DEditor;
class PlotStatusLabel;
class QAction;

//! Plots realdata, simulated data and relative difference map during the course of the fit.

class Fit2DFrame : public DataAccessWidget {
    Q_OBJECT
public:
    explicit Fit2DFrame(QWidget* parent = nullptr);

    void setJobOrDatafileItem(QObject* job_item) override;

    QList<QAction*> actionList() override;

private:
    void onResetViewAction();
    void connectItems();
    void updateDiffData();

    ColorMapCanvas* m_realCanvas;
    ColorMapCanvas* m_simuCanvas;
    ColorMapCanvas* m_diffCanvas;
    FitFlowWidget* m_fitFlowWidget;
    PlotStatusLabel* m_statusLabel;
    Scale2DEditor* m_propertyWidget;

    QAction* m_resetViewAction;
    QAction* m_togglePropertiesAction;
};

#endif // BORNAGAIN_GUI_VIEW_FRAME_FIT2DFRAME_H
